/****************************************************************************
** Meta object code from reading C++ file 'player_widget.h'
**
** Created: Sat Feb 21 18:01:58 2009
**      by: The Qt Meta Object Compiler version 59 (Qt 4.4.3)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "player_widget.h"
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'player_widget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 59
#error "This file was generated using the moc from 4.4.3. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
static const uint qt_meta_data_PlayerWidget[] = {

 // content:
       1,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   10, // methods
       0,    0, // properties
       0,    0, // enums/sets

 // signals: signature, parameters, type, tag, flags
      14,   13,   13,   13, 0x05,
      33,   28,   13,   13, 0x05,
      56,   28,   13,   13, 0x05,

 // slots: signature, parameters, type, tag, flags
      76,   13,   13,   13, 0x0a,
      86,   13,   13,   13, 0x08,
     117,   13,   13,   13, 0x08,
     147,   13,   13,   13, 0x08,
     175,   13,   13,   13, 0x08,
     207,   13,   13,   13, 0x08,

       0        // eod
};

static const char qt_meta_stringdata_PlayerWidget[] = {
    "PlayerWidget\0\0gameUpdated()\0iMsg\0"
    "notifyProblem(QString)\0notifyInfo(QString)\0"
    "refresh()\0on_pushButtonShuffle_clicked()\0"
    "on_pushButtonChange_clicked()\0"
    "on_pushButtonPass_clicked()\0"
    "on_lineEditChange_textChanged()\0"
    "on_lineEditChange_returnPressed()\0"
};

const QMetaObject PlayerWidget::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_PlayerWidget,
      qt_meta_data_PlayerWidget, 0 }
};

const QMetaObject *PlayerWidget::metaObject() const
{
    return &staticMetaObject;
}

void *PlayerWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_PlayerWidget))
        return static_cast<void*>(const_cast< PlayerWidget*>(this));
    return QWidget::qt_metacast(_clname);
}

int PlayerWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: gameUpdated(); break;
        case 1: notifyProblem((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 2: notifyInfo((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 3: refresh(); break;
        case 4: on_pushButtonShuffle_clicked(); break;
        case 5: on_pushButtonChange_clicked(); break;
        case 6: on_pushButtonPass_clicked(); break;
        case 7: on_lineEditChange_textChanged(); break;
        case 8: on_lineEditChange_returnPressed(); break;
        }
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void PlayerWidget::gameUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 0, 0);
}

// SIGNAL 1
void PlayerWidget::notifyProblem(QString _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void PlayerWidget::notifyInfo(QString _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
static const uint qt_meta_data_PlayerTabWidget[] = {

 // content:
       1,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   10, // methods
       0,    0, // properties
       0,    0, // enums/sets

 // signals: signature, parameters, type, tag, flags
      17,   16,   16,   16, 0x05,
      33,   16,   16,   16, 0x05,
      52,   47,   16,   16, 0x05,
      75,   47,   16,   16, 0x05,
     101,   95,   16,   16, 0x05,

 // slots: signature, parameters, type, tag, flags
     136,  130,   16,   16, 0x0a,
     157,   16,   16,   16, 0x0a,
     167,   16,   16,   16, 0x08,

       0        // eod
};

static const char qt_meta_stringdata_PlayerTabWidget[] = {
    "PlayerTabWidget\0\0refreshSignal()\0"
    "gameUpdated()\0iMsg\0notifyProblem(QString)\0"
    "notifyInfo(QString)\0iRack\0"
    "trainingRackUpdated(QString)\0iGame\0"
    "setGame(PublicGame*)\0refresh()\0"
    "changeCurrentPlayer(int)\0"
};

const QMetaObject PlayerTabWidget::staticMetaObject = {
    { &QTabWidget::staticMetaObject, qt_meta_stringdata_PlayerTabWidget,
      qt_meta_data_PlayerTabWidget, 0 }
};

const QMetaObject *PlayerTabWidget::metaObject() const
{
    return &staticMetaObject;
}

void *PlayerTabWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_PlayerTabWidget))
        return static_cast<void*>(const_cast< PlayerTabWidget*>(this));
    return QTabWidget::qt_metacast(_clname);
}

int PlayerTabWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTabWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: refreshSignal(); break;
        case 1: gameUpdated(); break;
        case 2: notifyProblem((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 3: notifyInfo((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 4: trainingRackUpdated((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: setGame((*reinterpret_cast< PublicGame*(*)>(_a[1]))); break;
        case 6: refresh(); break;
        case 7: changeCurrentPlayer((*reinterpret_cast< int(*)>(_a[1]))); break;
        }
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void PlayerTabWidget::refreshSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 0, 0);
}

// SIGNAL 1
void PlayerTabWidget::gameUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 1, 0);
}

// SIGNAL 2
void PlayerTabWidget::notifyProblem(QString _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void PlayerTabWidget::notifyInfo(QString _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void PlayerTabWidget::trainingRackUpdated(const QString & _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
QT_END_MOC_NAMESPACE
